@@ -2,8 +2,6 @@ type Foo = {
 };
 function foo() {
     type Foo__2 = string | number;
-    const foo__2 = {
-    } as Foo__2;
+    const foo__2 = {} as Foo__2;
 }
-const bar = {
-} as Foo;
+const bar = {} as Foo;
