@@ -70,8 +70,14 @@ impl Visit for AssertNoEmptyCtxt {
 
     fn visit_member_expr(&mut self, n: &MemberExpr) {
         n.obj.visit_with(self);
-        if n.computed {
-            n.prop.visit_with(self);
+        if let MemberProp::Computed(c) = &n.prop {
+            c.visit_with(self);
+        }
+    }
+
+    fn visit_super_prop_expr(&mut self, n: &SuperPropExpr) {
+        if let SuperProp::Computed(c) = &n.prop {
+            c.visit_with(self);
         }
     }
 
